==> eslint-plugin-check-file-2.1.0.tgz: package/lib/rules/filename-naming-convention.js <==
/**
 * @file The filename should follow the filename naming convention
 * @author Duke Luo
 */
'use strict';

const { getFilename, getBasename, getFilePath } = require('../utils/filename');
const {
  checkSettings,
  namingPatternValidator,
  globPatternValidator,
} = require('../utils/settings');
const { getDocUrl } = require('../utils/doc');
const { matchRule } = require('../utils/match');

/** @typedef {module:eslint} ESLint */
/**
 * @type {ESLint.Rule.RuleModule}
 */
module.exports = {
  meta: {
    type: 'layout',
    docs: {
      description: 'The filename should follow the filename naming convention',
      category: 'Layout & Formatting',
      recommended: false,
      url: getDocUrl('filename-naming-convention'),
    },
    fixable: null,
    schema: [
      {
        additionalProperties: {
          type: 'string',
        },
      },
      {
        type: 'object',
        properties: {
          ignoreMiddleExtensions: { type: 'boolean' },
        },
      },
    ],
  },

  create(context) {
    return {
      Program: (node) => {
        const rules = context.options[0];
        const { ignoreMiddleExtensions } = context.options[1] || {};

        const invalidPattern = checkSettings(
          rules,
          globPatternValidator,
          namingPatternValidator
        );

        if (invalidPattern) {
          context.report({
            node,
            message:
              'There is an invalid pattern "{{invalidPattern}}", please check it',
            data: {
              invalidPattern,
            },
          });
          return;
        }

        const filenameWithPath = getFilePath(context);
        const filename = getFilename(filenameWithPath);

        for (const [fexPattern, namingPattern] of Object.entries(rules)) {
          const matchResult = matchRule(
            filenameWithPath,
            fexPattern,
            getBasename(filename, ignoreMiddleExtensions),
            namingPattern
          );

          if (matchResult) {
            const { pattern } = matchResult;
            context.report({
              node,
              message:
                'The filename "{{filename}}" does not match the "{{pattern}}" style',
              data: {
                filename,
                pattern,
              },
            });
            return;
          }
        }
      },
    };
  },
};

==> eslint-plugin-check-file-2.2.0.tgz: package/lib/rules/filename-naming-convention.js <==
/**
 * @file The filename should follow the filename naming convention
 * @author Duke Luo
 */
'use strict';

const { transformRuleWithGroupCapture } = require('../utils/transform');
const { getFilename, getBasename, getFilePath } = require('../utils/filename');
const {
  checkSettings,
  fileNamingPatternValidator,
  globPatternValidator,
} = require('../utils/settings');
const { getDocUrl } = require('../utils/doc');
const { matchRule } = require('../utils/match');

/** @typedef {module:eslint} ESLint */
/**
 * @type {ESLint.Rule.RuleModule}
 */
module.exports = {
  meta: {
    type: 'layout',
    docs: {
      description: 'The filename should follow the filename naming convention',
      category: 'Layout & Formatting',
      recommended: false,
      url: getDocUrl('filename-naming-convention'),
    },
    fixable: null,
    schema: [
      {
        additionalProperties: {
          type: 'string',
        },
      },
      {
        type: 'object',
        properties: {
          ignoreMiddleExtensions: { type: 'boolean' },
        },
      },
    ],
  },

  create(context) {
    return {
      Program: (node) => {
        const filenameWithPath = getFilePath(context);
        const filename = getFilename(filenameWithPath);

        const rules = context.options[0] || {};
        const { ignoreMiddleExtensions } = context.options[1] || {};

        const invalidPattern = checkSettings(
          rules,
          globPatternValidator,
          fileNamingPatternValidator
        );

        if (invalidPattern) {
          context.report({
            node,
            message:
              'There is an invalid pattern "{{invalidPattern}}", please check it',
            data: {
              invalidPattern,
            },
          });
          return;
        }

        for (const [
          originalFexPattern,
          originalNamingPattern,
        ] of Object.entries(rules)) {
          try {
            const [fexPattern, namingPattern] = transformRuleWithGroupCapture(
              [originalFexPattern, originalNamingPattern],
              filenameWithPath
            );

            const matchResult = matchRule(
              filenameWithPath,
              fexPattern,
              getBasename(filename, ignoreMiddleExtensions),
              namingPattern
            );

            if (matchResult) {
              throw new Error(
                `The filename "${filename}" does not match the "${originalNamingPattern}" style`
              );
            }
          } catch (error) {
            context.report({
              node,
              message: error.message,
            });
          }
        }
      },
    };
  },
};
